# OpenSCAD model package makefile fragment
#
# Copyright (C) 2016, 2017  Patrick McDermott
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

OBJECTS = $(SOURCES:.scad=.stl)
DEPENDS = $(SOURCES:.scad=.d)

DIST_DIR = $(PACKAGE_NAME)-$(PACKAGE_VERSION)
DIST_COMMON = Makefile build.mk
DIST_FILES = $(DIST_COMMON) $(EXTRA_DIST)
DIST_TARGETS = dist-gzip dist-bzip2 dist-xz
DO_RM_DIST_DIR = @

V = 0
V_OPENSCAD = $(V_OPENSCAD_$(V))
V_OPENSCAD_0 = @printf '  OPENSCAD %s\n' $@;
V_OPENSCAD_1 =
Q = $(Q_$(V))
Q_0 = @
Q_1 =

OPENSCAD = openscad
MKDIR_P = mkdir -p
TAR = tar

.SUFFIXES:
.SUFFIXES: .scad .stl

all: $(OBJECTS)

-include $(DEPENDS)

clean:
	rm -f $(OBJECTS)

distclean: clean
	rm -f $(DEPENDS)

distdir: all
	@set -e; \
	rm -Rf $(DIST_DIR); \
	for f in $(DIST_FILES); do \
		f=./$${f}; \
		$(MKDIR_P) $(DIST_DIR)/$${f%/*}; \
		cp -p $${f} $(DIST_DIR)/$${f%/*}; \
	done; \
	for d in $(DEPENDS); do \
		f=$${d%.d}.scad; \
		p=$$(sed -n "\$$s|\t\(.*\)$${f}|\1|p" $${d}); \
		tail -n +2 $${d} | while read -r l; do \
			l=$${l% \\}; \
			case $${l} in \
				$${p}*) \
					l=$${l#$${p}}; \
					$(MKDIR_P) $(DIST_DIR)/$${l%/*}; \
					cp -p $${l} $(DIST_DIR)/$${l%/*}; \
					;; \
			esac; \
		done; \
	done

dist-gzip: distdir
	$(TAR) -c $(DIST_DIR) | gzip -c -9 >$(DIST_DIR).tar.gz
	$(DO_RM_DIST_DIR)rm -Rf $(DIST_DIR)

dist-bzip2: distdir
	$(TAR) -c $(DIST_DIR) | bzip2 -c -9 >$(DIST_DIR).tar.bz2
	$(DO_RM_DIST_DIR)rm -Rf $(DIST_DIR)

dist-xz: distdir
	$(TAR) -c $(DIST_DIR) | xz -c -9e >$(DIST_DIR).tar.xz
	$(DO_RM_DIST_DIR)rm -Rf $(DIST_DIR)

dist dist-all:
	$(MAKE) $(DIST_TARGETS) DO_RM_DIST_DIR='@: '
	$(DO_RM_DIST_DIR)rm -Rf $(DIST_DIR)

.scad.stl:
	$(V_OPENSCAD)$(OPENSCAD) -d $*.d -o $@ $<
