/*
 * 2.5" form factor (SFF-8201) drive height adapter
 *
 * Copyright (C) 2016  Patrick McDermott
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

$fn = 32;

module sff8201_ha_outside(out_l, out_w, out_h, out_b)
{
	hull() {
		for (x = [out_l / -2 + out_b, out_l / 2 - out_b]) {
			for (y = [out_w / -2 + out_b,
					out_w / 2 - out_b]) {
				translate([x, y, 0])
					cylinder(out_h - out_b, out_b, out_b);
				translate([x, y, out_h - out_b])
					sphere(out_b);
			}
		}
	}
}

module sff8201_ha_inside_top_bevel(in_top_b)
{
	difference() {
		square([in_top_b, in_top_b], false);
		translate([in_top_b, 0, 0]) circle(in_top_b);
	}
}

module sff8201_ha_inside_top_corner_bevel(in_top_b, in_cor_b)
{
	rotate_extrude()
		union() {
			square([in_cor_b, in_top_b], false);
			translate([in_cor_b, 0, 0])
				sff8201_ha_inside_top_bevel(in_top_b);
		}
}

module sff8201_ha_inside_top_edge_bevel(in_top_b, l)
{
	rotate([90, 0, 0]) mirror([0, 0, 0]) translate([0, 0, l / -2])
		linear_extrude(height = l) {
			translate([-1 * in_top_b, 0, 0])
				square([in_top_b, in_top_b]);
			sff8201_ha_inside_top_bevel(in_top_b);
	}
}

module sff8201_ha_inside(in_l, in_w, in_h, in_cor_b, in_top_b)
{
	union() {
		// Body
		hull() {
			for (x = [in_l / -2 + in_cor_b, in_l / 2 - in_cor_b]) {
				for (y = [in_w / -2 + in_cor_b,
						in_w / 2 - in_cor_b]) {
					translate([x, y, -1])
						cylinder(in_h + 2,
							in_cor_b, in_cor_b);
				}
			}
		}
		// Left bevel
		translate([in_l / -2, 0, in_h - in_top_b]) rotate([0, 0, 180])
			sff8201_ha_inside_top_edge_bevel(in_top_b,
				in_w - in_cor_b * 2);
		// Right bevel
		translate([in_l / 2, 0, in_h - in_top_b]) rotate([0, 0, 0])
			sff8201_ha_inside_top_edge_bevel(in_top_b,
				in_w - in_cor_b * 2);
		// Front bevel
		translate([0, in_w / -2, in_h - in_top_b]) rotate([0, 0, 270])
			sff8201_ha_inside_top_edge_bevel(in_top_b,
				in_l - in_cor_b * 2);
		// Back bevel
		translate([0, in_w / 2, in_h - in_top_b]) rotate([0, 0, 90])
			sff8201_ha_inside_top_edge_bevel(in_top_b,
				in_l - in_cor_b * 2);
		// Corner bevels
		for (x = [in_l / -2 + in_cor_b, in_l / 2 - in_cor_b]) {
			for (y = [in_w / -2 + in_cor_b, in_w / 2 - in_cor_b]) {
				translate([x, y, in_h - in_top_b])
					sff8201_ha_inside_top_corner_bevel(
						in_top_b, in_cor_b);
			}
		}
	}
}

module sff8201_ha(out_l, out_w, out_h, out_b, in_l, in_w, in_cor_b, in_top_b)
{
	difference() {
		sff8201_ha_outside(out_l, out_w, out_h, out_b);
		sff8201_ha_inside(in_l, in_w, out_h, in_cor_b, in_top_b);
	}
}
