/*
 * 2x1 runner of 2.5" form factor (SFF-8201) drive 2.5-mm height adapters
 *
 * Copyright (C) 2016  Patrick McDermott
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

include <../lib/sff8201-ha.scad>

/* Height adapter dimensions */
   out_l = 100.00;  /* Length (SFF-8201 dimension A6, typ.) */
   out_w =  69.85;  /* Width (SFF-8201 dimension A4) */
   out_h =   2.50;  /* Height (SFF-8201 dimension A1, 9.50 - 7.00) */
   out_b =   1.25;  /* Corner and top bevel */
    in_l =  80.00;  /* Inner void length */
    in_w =  60.00;  /* Inner void width */
in_cor_b =   1.25;  /* Inner void corner bevel */
in_top_b =   0.25;  /* Inner void top bevel */

/* Runner and gate dimensions */
main_run_w =  1.00;  /* Main runner width */
main_run_h =  1.00;  /* Main runner height/depth/thickness */
part_run_l =  1.00;  /* Part runner length */
part_run_w =  1.00;  /* Part runner width */
part_run_h =  1.00;  /* Part runner height/depth/thickness */
    gate_l =  1.00;  /* Gate length */
    gate_w =  1.00;  /* Gate width */
    gate_h =  0.50;  /* Gate height/depth/thickness */
    gate_o = 30.00;  /* Offset of gate centers from part center */

union() {
	/* Main runner */
	translate([0, 0, main_run_h/2])
		cube([main_run_w, gate_o*2 + part_run_w, main_run_h],
			center = true);

	for (i = [-1, 1]) {
		for (j = [-1, 1]) {
			/* Part runners */
			translate([i * (main_run_w/2 + part_run_l/2),
				j * gate_o, part_run_h/2])
				cube([part_run_l, part_run_w, part_run_h],
					center = true);
			/* Gates */
			translate([i * (main_run_w/2 + part_run_l + gate_l/2),
				j * gate_o, gate_h/2])
				cube([gate_l, gate_w, gate_h], center = true);
		}
		/* Parts */
		translate([i * (out_w/2 + main_run_w/2 + part_run_l + gate_l),
			0, 0])
			rotate([0, 0, 90])
			sff8201_ha(out_l, out_w, out_h, out_b, in_l, in_w,
				in_cor_b, in_top_b);
	}
}
